@@ -1,15 +1,16 @@
 /*
  *
- *  This file is part of MUMPS 5.1.2, released
- *  on Mon Oct  2 07:37:01 UTC 2017
+ *  This file is part of MUMPS 5.6.0, released
+ *  on Wed Apr 19 15:50:57 UTC 2023
  *
  *
- *  Copyright 1991-2017 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
- *  University of Bordeaux.
+ *  Copyright 1991-2023 CERFACS, CNRS, ENS Lyon, INP Toulouse, Inria,
+ *  Mumps Technologies, University of Bordeaux.
  *
  *  This version of MUMPS is provided to you free of charge. It is
- *  released under the CeCILL-C license:
- *  http://www.cecill.info/licences/Licence_CeCILL-C_V1-en.html
+ *  released under the CeCILL-C license 
+ *  (see doc/CeCILL-C_V1-en.txt, doc/CeCILL-C_V1-fr.txt, and
+ *  https://cecill.info/licences/Licence_CeCILL-C_V1-en.html)
  *
  */
 #include "mumps_io_basic.h"
@@ -563,7 +564,7 @@ MUMPS_INT mumps_init_file_name(char* mumps_dir,char* mumps_file,
   }
   if(tmp_fname!=NULL){
 #if ! defined( MUMPS_WIN32 )
-      sprintf(base_name,"_%s%d_XXXXXX",mumps_base,*_myid);
+      sprintf(base_name,"_%s%d_XXXXXX",mumps_base,(int)*_myid);
 #else
       sprintf(base_name,"_%s%d",mumps_base,*_myid);
 #endif
@@ -574,7 +575,7 @@ MUMPS_INT mumps_init_file_name(char* mumps_dir,char* mumps_file,
       sprintf(mumps_ooc_file_prefix,"%s%s%s%s",tmp_dir,SEPARATOR,tmp_fname,base_name);
   }else{
 #if ! defined( MUMPS_WIN32 )
-    sprintf(base_name,"%s%s%d_XXXXXX",SEPARATOR,mumps_base,*_myid);
+    sprintf(base_name,"%s%s%d_XXXXXX",SEPARATOR,mumps_base,(int)*_myid);
 #else
     sprintf(base_name,"%s%s%d",SEPARATOR,mumps_base,*_myid);
 #endif
